'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _sha = require('./lib/sha256.js');

var _sha2 = _interopRequireDefault(_sha);

var _cacheManager = require('cache-manager');

var _cacheManager2 = _interopRequireDefault(_cacheManager);

var _cacheManagerRedis = require('cache-manager-redis');

var _cacheManagerRedis2 = _interopRequireDefault(_cacheManagerRedis);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REDIS_HOST = process.env.REDIS_HOST || '127.0.0.1';
var REDIS_PORT = process.env.REDIS_PORT || 6379;

var redisCache = _cacheManager2.default.caching({
  store: _cacheManagerRedis2.default,
  host: REDIS_HOST,
  port: REDIS_PORT,
  db: 0,
  ttl: 86400
});

_bluebird2.default.promisifyAll(redisCache);

function getCacheKey(url) {
  return 'scraperjs-url-cache:' + (0, _sha2.default)(url);
}

exports.default = {
  get: function get(url) {
    return redisCache.getAsync(getCacheKey(url));
  },
  set: function set(url, value, ttl) {
    // redisCache expects ttl in seconds not ms
    return redisCache.setAsync(getCacheKey(url), value, { ttl: ttl / 1000 });
  }
};